# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageGridPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkShrinkImageFilterPython
else:
    import _itkShrinkImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImageToImageFilterBPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageToImageFilterAPython

def itkShrinkImageFilterICF2ICF2_New():
    return itkShrinkImageFilterICF2ICF2.New()

class itkShrinkImageFilterICF2ICF2(itk.itkImageToImageFilterBPython.itkImageToImageFilterICF2ICF2):
    r"""Proxy of C++ itkShrinkImageFilterICF2ICF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICF2ICF2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICF2ICF2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICF2ICF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICF2ICF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICF2ICF2

        Create a new object of the class itkShrinkImageFilterICF2ICF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICF2ICF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICF2ICF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICF2ICF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICF2ICF2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICF2ICF2_swigregister(itkShrinkImageFilterICF2ICF2)

def itkShrinkImageFilterICF3ICF3_New():
    return itkShrinkImageFilterICF3ICF3.New()

class itkShrinkImageFilterICF3ICF3(itk.itkImageToImageFilterBPython.itkImageToImageFilterICF3ICF3):
    r"""Proxy of C++ itkShrinkImageFilterICF3ICF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICF3ICF3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICF3ICF3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICF3ICF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICF3ICF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICF3ICF3

        Create a new object of the class itkShrinkImageFilterICF3ICF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICF3ICF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICF3ICF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICF3ICF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICF3ICF3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICF3ICF3_swigregister(itkShrinkImageFilterICF3ICF3)

def itkShrinkImageFilterICVF22ICVF22_New():
    return itkShrinkImageFilterICVF22ICVF22.New()

class itkShrinkImageFilterICVF22ICVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF22ICVF22):
    r"""Proxy of C++ itkShrinkImageFilterICVF22ICVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF22ICVF22_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF22ICVF22_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF22ICVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF22ICVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF22ICVF22

        Create a new object of the class itkShrinkImageFilterICVF22ICVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF22ICVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF22ICVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF22ICVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF22ICVF22 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF22ICVF22_swigregister(itkShrinkImageFilterICVF22ICVF22)

def itkShrinkImageFilterICVF23ICVF23_New():
    return itkShrinkImageFilterICVF23ICVF23.New()

class itkShrinkImageFilterICVF23ICVF23(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF23ICVF23):
    r"""Proxy of C++ itkShrinkImageFilterICVF23ICVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF23ICVF23_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF23ICVF23_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF23ICVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF23ICVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF23ICVF23

        Create a new object of the class itkShrinkImageFilterICVF23ICVF23 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF23ICVF23.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF23ICVF23.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF23ICVF23.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF23ICVF23 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF23ICVF23_swigregister(itkShrinkImageFilterICVF23ICVF23)

def itkShrinkImageFilterICVF32ICVF32_New():
    return itkShrinkImageFilterICVF32ICVF32.New()

class itkShrinkImageFilterICVF32ICVF32(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF32ICVF32):
    r"""Proxy of C++ itkShrinkImageFilterICVF32ICVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF32ICVF32_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF32ICVF32_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF32ICVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF32ICVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF32ICVF32

        Create a new object of the class itkShrinkImageFilterICVF32ICVF32 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF32ICVF32.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF32ICVF32.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF32ICVF32.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF32ICVF32 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF32ICVF32_swigregister(itkShrinkImageFilterICVF32ICVF32)

def itkShrinkImageFilterICVF33ICVF33_New():
    return itkShrinkImageFilterICVF33ICVF33.New()

class itkShrinkImageFilterICVF33ICVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF33ICVF33):
    r"""Proxy of C++ itkShrinkImageFilterICVF33ICVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF33ICVF33_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF33ICVF33_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF33ICVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF33ICVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF33ICVF33

        Create a new object of the class itkShrinkImageFilterICVF33ICVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF33ICVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF33ICVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF33ICVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF33ICVF33 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF33ICVF33_swigregister(itkShrinkImageFilterICVF33ICVF33)

def itkShrinkImageFilterICVF42ICVF42_New():
    return itkShrinkImageFilterICVF42ICVF42.New()

class itkShrinkImageFilterICVF42ICVF42(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF42ICVF42):
    r"""Proxy of C++ itkShrinkImageFilterICVF42ICVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF42ICVF42_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF42ICVF42_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF42ICVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF42ICVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF42ICVF42

        Create a new object of the class itkShrinkImageFilterICVF42ICVF42 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF42ICVF42.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF42ICVF42.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF42ICVF42.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF42ICVF42 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF42ICVF42_swigregister(itkShrinkImageFilterICVF42ICVF42)

def itkShrinkImageFilterICVF43ICVF43_New():
    return itkShrinkImageFilterICVF43ICVF43.New()

class itkShrinkImageFilterICVF43ICVF43(itk.itkImageToImageFilterAPython.itkImageToImageFilterICVF43ICVF43):
    r"""Proxy of C++ itkShrinkImageFilterICVF43ICVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterICVF43ICVF43_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterICVF43ICVF43_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterICVF43ICVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterICVF43ICVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterICVF43ICVF43

        Create a new object of the class itkShrinkImageFilterICVF43ICVF43 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterICVF43ICVF43.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterICVF43ICVF43.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterICVF43ICVF43.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterICVF43ICVF43 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterICVF43ICVF43_swigregister(itkShrinkImageFilterICVF43ICVF43)

def itkShrinkImageFilterIF2IF2_New():
    return itkShrinkImageFilterIF2IF2.New()

class itkShrinkImageFilterIF2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF2IF2):
    r"""Proxy of C++ itkShrinkImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIF2IF2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIF2IF2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIF2IF2

        Create a new object of the class itkShrinkImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIF2IF2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIF2IF2_swigregister(itkShrinkImageFilterIF2IF2)

def itkShrinkImageFilterIF3IF3_New():
    return itkShrinkImageFilterIF3IF3.New()

class itkShrinkImageFilterIF3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIF3IF3):
    r"""Proxy of C++ itkShrinkImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIF3IF3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIF3IF3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIF3IF3

        Create a new object of the class itkShrinkImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIF3IF3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIF3IF3_swigregister(itkShrinkImageFilterIF3IF3)

def itkShrinkImageFilterIRGBAUC2IRGBAUC2_New():
    return itkShrinkImageFilterIRGBAUC2IRGBAUC2.New()

class itkShrinkImageFilterIRGBAUC2IRGBAUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBAUC2IRGBAUC2):
    r"""Proxy of C++ itkShrinkImageFilterIRGBAUC2IRGBAUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIRGBAUC2IRGBAUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIRGBAUC2IRGBAUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIRGBAUC2IRGBAUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIRGBAUC2IRGBAUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIRGBAUC2IRGBAUC2

        Create a new object of the class itkShrinkImageFilterIRGBAUC2IRGBAUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIRGBAUC2IRGBAUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIRGBAUC2IRGBAUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIRGBAUC2IRGBAUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIRGBAUC2IRGBAUC2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC2IRGBAUC2_swigregister(itkShrinkImageFilterIRGBAUC2IRGBAUC2)

def itkShrinkImageFilterIRGBAUC3IRGBAUC3_New():
    return itkShrinkImageFilterIRGBAUC3IRGBAUC3.New()

class itkShrinkImageFilterIRGBAUC3IRGBAUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBAUC3IRGBAUC3):
    r"""Proxy of C++ itkShrinkImageFilterIRGBAUC3IRGBAUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIRGBAUC3IRGBAUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIRGBAUC3IRGBAUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIRGBAUC3IRGBAUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIRGBAUC3IRGBAUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIRGBAUC3IRGBAUC3

        Create a new object of the class itkShrinkImageFilterIRGBAUC3IRGBAUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIRGBAUC3IRGBAUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIRGBAUC3IRGBAUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIRGBAUC3IRGBAUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIRGBAUC3IRGBAUC3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIRGBAUC3IRGBAUC3_swigregister(itkShrinkImageFilterIRGBAUC3IRGBAUC3)

def itkShrinkImageFilterIRGBUC2IRGBUC2_New():
    return itkShrinkImageFilterIRGBUC2IRGBUC2.New()

class itkShrinkImageFilterIRGBUC2IRGBUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBUC2IRGBUC2):
    r"""Proxy of C++ itkShrinkImageFilterIRGBUC2IRGBUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIRGBUC2IRGBUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIRGBUC2IRGBUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIRGBUC2IRGBUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIRGBUC2IRGBUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIRGBUC2IRGBUC2

        Create a new object of the class itkShrinkImageFilterIRGBUC2IRGBUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIRGBUC2IRGBUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIRGBUC2IRGBUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIRGBUC2IRGBUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIRGBUC2IRGBUC2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC2IRGBUC2_swigregister(itkShrinkImageFilterIRGBUC2IRGBUC2)

def itkShrinkImageFilterIRGBUC3IRGBUC3_New():
    return itkShrinkImageFilterIRGBUC3IRGBUC3.New()

class itkShrinkImageFilterIRGBUC3IRGBUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIRGBUC3IRGBUC3):
    r"""Proxy of C++ itkShrinkImageFilterIRGBUC3IRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIRGBUC3IRGBUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIRGBUC3IRGBUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIRGBUC3IRGBUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIRGBUC3IRGBUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIRGBUC3IRGBUC3

        Create a new object of the class itkShrinkImageFilterIRGBUC3IRGBUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIRGBUC3IRGBUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIRGBUC3IRGBUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIRGBUC3IRGBUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIRGBUC3IRGBUC3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIRGBUC3IRGBUC3_swigregister(itkShrinkImageFilterIRGBUC3IRGBUC3)

def itkShrinkImageFilterISS2ISS2_New():
    return itkShrinkImageFilterISS2ISS2.New()

class itkShrinkImageFilterISS2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS2ISS2):
    r"""Proxy of C++ itkShrinkImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterISS2ISS2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterISS2ISS2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterISS2ISS2

        Create a new object of the class itkShrinkImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterISS2ISS2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterISS2ISS2_swigregister(itkShrinkImageFilterISS2ISS2)

def itkShrinkImageFilterISS3ISS3_New():
    return itkShrinkImageFilterISS3ISS3.New()

class itkShrinkImageFilterISS3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterISS3ISS3):
    r"""Proxy of C++ itkShrinkImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterISS3ISS3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterISS3ISS3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterISS3ISS3

        Create a new object of the class itkShrinkImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterISS3ISS3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterISS3ISS3_swigregister(itkShrinkImageFilterISS3ISS3)

def itkShrinkImageFilterIUC2IUC2_New():
    return itkShrinkImageFilterIUC2IUC2.New()

class itkShrinkImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkShrinkImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIUC2IUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIUC2IUC2_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIUC2IUC2

        Create a new object of the class itkShrinkImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIUC2IUC2 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIUC2IUC2_swigregister(itkShrinkImageFilterIUC2IUC2)

def itkShrinkImageFilterIUC3IUC3_New():
    return itkShrinkImageFilterIUC3IUC3.New()

class itkShrinkImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkShrinkImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIUC3IUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIUC3IUC3_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIUC3IUC3

        Create a new object of the class itkShrinkImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIUC3IUC3 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIUC3IUC3_swigregister(itkShrinkImageFilterIUC3IUC3)

def itkShrinkImageFilterIVF22IVF22_New():
    return itkShrinkImageFilterIVF22IVF22.New()

class itkShrinkImageFilterIVF22IVF22(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF22IVF22):
    r"""Proxy of C++ itkShrinkImageFilterIVF22IVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF22IVF22_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF22IVF22_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF22IVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF22IVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF22IVF22

        Create a new object of the class itkShrinkImageFilterIVF22IVF22 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF22IVF22.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF22IVF22.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF22IVF22.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF22IVF22 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF22IVF22_swigregister(itkShrinkImageFilterIVF22IVF22)

def itkShrinkImageFilterIVF23IVF23_New():
    return itkShrinkImageFilterIVF23IVF23.New()

class itkShrinkImageFilterIVF23IVF23(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF23IVF23):
    r"""Proxy of C++ itkShrinkImageFilterIVF23IVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF23IVF23_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF23IVF23_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF23IVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF23IVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF23IVF23

        Create a new object of the class itkShrinkImageFilterIVF23IVF23 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF23IVF23.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF23IVF23.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF23IVF23.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF23IVF23 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF23IVF23_swigregister(itkShrinkImageFilterIVF23IVF23)

def itkShrinkImageFilterIVF32IVF32_New():
    return itkShrinkImageFilterIVF32IVF32.New()

class itkShrinkImageFilterIVF32IVF32(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF32IVF32):
    r"""Proxy of C++ itkShrinkImageFilterIVF32IVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF32IVF32_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF32IVF32_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF32IVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF32IVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF32IVF32

        Create a new object of the class itkShrinkImageFilterIVF32IVF32 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF32IVF32.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF32IVF32.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF32IVF32.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF32IVF32 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF32IVF32_swigregister(itkShrinkImageFilterIVF32IVF32)

def itkShrinkImageFilterIVF33IVF33_New():
    return itkShrinkImageFilterIVF33IVF33.New()

class itkShrinkImageFilterIVF33IVF33(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF33IVF33):
    r"""Proxy of C++ itkShrinkImageFilterIVF33IVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF33IVF33_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF33IVF33_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF33IVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF33IVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF33IVF33

        Create a new object of the class itkShrinkImageFilterIVF33IVF33 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF33IVF33.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF33IVF33.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF33IVF33.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF33IVF33 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF33IVF33_swigregister(itkShrinkImageFilterIVF33IVF33)

def itkShrinkImageFilterIVF42IVF42_New():
    return itkShrinkImageFilterIVF42IVF42.New()

class itkShrinkImageFilterIVF42IVF42(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF42IVF42):
    r"""Proxy of C++ itkShrinkImageFilterIVF42IVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF42IVF42_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF42IVF42_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI2

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI2"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF42IVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF42IVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF42IVF42

        Create a new object of the class itkShrinkImageFilterIVF42IVF42 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF42IVF42.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF42IVF42.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF42IVF42.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF42IVF42 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF42IVF42_swigregister(itkShrinkImageFilterIVF42IVF42)

def itkShrinkImageFilterIVF43IVF43_New():
    return itkShrinkImageFilterIVF43IVF43.New()

class itkShrinkImageFilterIVF43IVF43(itk.itkImageToImageFilterAPython.itkImageToImageFilterIVF43IVF43):
    r"""Proxy of C++ itkShrinkImageFilterIVF43IVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShrinkImageFilterIVF43IVF43_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShrinkImageFilterIVF43IVF43_Pointer"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_Clone(self)

    def SetShrinkFactors(self, *args):
        r"""
        SetShrinkFactors(self, _arg)

        Parameters
        ----------
        _arg: itkFixedArrayUI3

        SetShrinkFactors(self, factor)

        Parameters
        ----------
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_SetShrinkFactors(self, *args)

    def SetShrinkFactor(self, i, factor):
        r"""
        SetShrinkFactor(self, i, factor)

        Parameters
        ----------
        i: unsigned int
        factor: unsigned int

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_SetShrinkFactor(self, i, factor)

    def GetShrinkFactors(self):
        r"""GetShrinkFactors(self) -> itkFixedArrayUI3"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_GetShrinkFactors(self)

    def GenerateOutputInformation(self):
        r"""GenerateOutputInformation(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_GenerateOutputInformation(self)

    def GenerateInputRequestedRegion(self):
        r"""GenerateInputRequestedRegion(self)"""
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_GenerateInputRequestedRegion(self)
    InputConvertibleToOutputCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_InputConvertibleToOutputCheck
    
    SameDimensionCheck = _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_SameDimensionCheck
    
    __swig_destroy__ = _itkShrinkImageFilterPython.delete_itkShrinkImageFilterIVF43IVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShrinkImageFilterIVF43IVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShrinkImageFilterIVF43IVF43

        Create a new object of the class itkShrinkImageFilterIVF43IVF43 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShrinkImageFilterIVF43IVF43.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShrinkImageFilterIVF43IVF43.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShrinkImageFilterIVF43IVF43.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShrinkImageFilterIVF43IVF43 in _itkShrinkImageFilterPython:
_itkShrinkImageFilterPython.itkShrinkImageFilterIVF43IVF43_swigregister(itkShrinkImageFilterIVF43IVF43)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def shrink_image_filter(*args: itkt.ImageLike,  shrink_factors: Union[int, Sequence[int]]=..., shrink_factor: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ShrinkImageFilter"""
    import itk

    kwarg_typehints = { 'shrink_factors':shrink_factors,'shrink_factor':shrink_factor }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ShrinkImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def shrink_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageGrid.ShrinkImageFilter
    shrink_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    shrink_image_filter.__doc__ = filter_object.__doc__



